from pyimgaug3d.augmentation.src.base_augmentation import BaseAugmentation
from pyimgaug3d.augmentation.src.warp import GridWarp
from pyimgaug3d.augmentation.src.flip_augmentation import Flip
from pyimgaug3d.augmentation.src.identity import Identity


from pyimgaug3d.augmenters.src.base_augmenter import BaseAugmenter
from pyimgaug3d.utils import classical_round_tf

"""
accepts 2 images, the second one gets roudned
"""
class ImageSegmentationAugmenter(BaseAugmenter):
    def __call__(self, imgs):
        assert len(imgs) == 2, "only pass in [img, seg]"
        x, y = super().__call__(imgs)
        return x, classical_round_tf(y)

class ImageAugmenter(BaseAugmenter):
    def __call__(self, img):
        x = super().__call__([img])
        return x[0]


import tensorflow as tf
from pyimgaug3d.augmentation.src.base_augmentation import BaseAugmentation

class Identity(BaseAugmentation):
    def __init__(self):
        super().__init__()

    def __call__(self, imgs):
        imgs = [tf.convert_to_tensor(img) for img in imgs]
        return imgs


import random

class BaseAugmenter:
    def __init__(self):
        self.augmentation = []
    
    def add_augmentation(self, augmentation):
        self.augmentation.append(augmentation)

    def __call__(self, images):
        aug = random.choice(self.augmentation)
        return aug(images)